<?php
/**
 *
 * @link              https://taboola.com
 * @since             1.0.0
 * @package           Taboola_Best_Practice_Layout
 *
 * @wordpress-plugin
 * Plugin Name:       Taboola Best Practice Layout
 * Plugin URI:        https://taboola.com
 * Description:       Taboola Best Practice Layout is a WordPress plugin that generates optimized pages using Blocks based on Taboola's best practices  with just a single click.
 * Version:           1.2.2
 * Author:            Taboola 
 * Author URI:        https://taboola.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       Taboola-best-practice-layout
 */


 if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'includes/tbla_pxl.php';

// Add a custom menu item in the WordPress admin dashboard
add_action('admin_menu', 'custom_page_creation_menu');

function tbpl_enqueue() {
    wp_register_style('tbpl_style', plugins_url('/assets/css/style.css',__FILE__ ));
    wp_enqueue_style('tbpl_style');
    wp_register_script( 'tbpl_script', plugins_url('/assets/js/script.js',__FILE__ ),'','',true);
    wp_enqueue_script('tbpl_script');
}

add_action( 'admin_init','tbpl_enqueue');
function custom_page_creation_menu() {
    add_submenu_page(
        'tools.php',
        'Taboola Best Practice Layout', 
        'Taboola Best Practice Layout', 
        'manage_options', 
        'custom-page-creation', 
        'tpc_init', // Callback function
        'dashicons-clipboard' // Icon URL
    );
}

// Callback function to render the plugin page in the WordPress admin dashboard
function tpc_init() {
    $post_content =   file_get_contents(plugin_dir_path(__FILE__) . 'includes/layout.html');
   
    $tbla_account_id = get_option('tbla_account_id');
    if (!$tbla_account_id && isset($_POST['tbla_account_id'])) {
        $tbla_account_id = sanitize_text_field($_POST['tbla_account_id']);
    }
   

    if (isset($_POST['submit_tbla_create_page'])) {

        
        $tbla_event = "
        <!-- Taboola Event Code -->
            <script>
            _tfa.push({notify: 'event', name: '" . sanitize_text_field($_POST['tbla_event']) . "', id: " . $tbla_account_id . "});
            </script>
        <!-- End of Taboola Event Code -->";

        // Create a new page
        $post_data = array(
            'post_title' => 'Taboola Best Practice Layout', 
            'post_content' =>  $post_content . $tbla_event,
            'post_status' => 'draft',
            'post_author' => get_current_user_id(),
            'post_type' => 'page' 
        );


        // Insert the post into the database
        $post_id = wp_insert_post($post_data);


      
	
        $link = "post.php?post={$post_id}&action=edit";
        echo "<div class=\"updated\">
                <p>Page created successfully! Click <a href=\"{$link}\">here</a> to edit it.</p>
            </div>";
    }

    if (isset($_POST['submit_tbla_account_id'])) {
        $tbla_account_id = sanitize_text_field($_POST['tbla_account_id']);
        update_option('tbla_account_id', $tbla_account_id);
    }

    
    ?>
<div class="tbpl-wrap">
  <div class="tbpl">
        <div class="header">

        <h1>Taboola Best Practice Layout</h1>
        <svg id="logo" viewBox="0 0 700.26 190.69" fill="#0056f0" stock-width="0px">
        <title>Taboola Blog</title>
        <g>
            <g>
            <g>
                <path d="M37.06,40.59H0V6.77h114.79v33.82h-37.1l.02,99.12h-40.63l-.02-99.12Z"></path>
                <path d="M148.6,96.28c-4.46,2.2-9.48,3.47-14.49,4.55-8.18,1.81-12.45,3.82-12.49,10.31-.02,4.46,4.77,8.94,11.44,8.98,8.34.04,14.86-4.92,15.48-14.94l.05-8.91ZM183.73,118.19c-.05,7.23.28,15.4,4.32,21.54l-37.47-.22c-.91-2.6-1.45-6.5-1.24-9.09h-.38c-7.83,8.85-19.16,11.38-31.04,11.32-18.54-.11-33.88-9.1-33.78-29.32.18-30.42,35.79-29.1,54.54-32.51,5.01-.9,10.03-2.36,10.06-8.48.04-6.49-6.06-8.95-11.99-8.98-11.31-.05-13.58,5.68-13.78,9.75l-34.13-.19c1.26-27.07,26.88-31.38,49.7-31.25,45.99.27,45.52,19.38,45.4,37.92l-.22,39.51Z"></path>
                <path d="M240.33,68.07c-13.16-.07-16.2,12.34-16.27,23.64-.07,11.5,2.83,23.95,15.99,24.03,13.17.07,16.21-12.34,16.28-23.84.07-11.31-2.83-23.76-16-23.83M189.13,6.56h36.72l-.27,47.7h.37c5.61-8.13,15.46-12.9,26.41-12.84,32.26.19,40.82,27.69,40.69,50.32-.14,24.11-13.47,50.92-40.72,50.77-17.99-.11-23.52-7-28.12-13.16h-.37l-.07,10.36h-34.64V6.56Z"></path>
                <path d="M344.59,33.5c-13.92-.08-15.85,13.45-15.91,23.64-.05,10.2,1.72,23.94,15.63,24.03,13.91.07,15.85-13.63,15.91-23.84.06-10.2-1.72-23.75-15.63-23.83M344.15,107.87c-36.17-.21-52.36-24.23-52.19-50.94.16-26.71,16.61-50.35,52.78-50.13,36.17.2,52.36,24.03,52.2,50.75-.16,26.7-16.61,50.54-52.78,50.33"></path>
                <path d="M435.72,33.5c-13.91-.08-15.84,13.45-15.9,23.65-.07,10.2,1.71,23.93,15.62,24.02,13.9.08,15.84-13.63,15.9-23.83.06-10.2-1.72-23.76-15.63-23.83M435.29,107.88c-36.16-.22-52.34-24.24-52.18-50.95.15-26.7,16.61-50.35,52.77-50.14,36.17.21,52.35,24.04,52.2,50.75-.16,26.71-16.62,50.54-52.79,50.34"></path>
                <path d="M492.04,6.8h35.94v132.92h-35.94V6.8Z"></path>
                <path d="M594.92,95.96c-4.46,2.19-9.48,3.46-14.48,4.54-8.19,1.81-12.45,3.83-12.49,10.32-.03,4.45,4.77,8.93,11.44,8.97,8.35.04,14.87-4.92,15.48-14.94l.05-8.89ZM630.26,117.85c-.03,7.23-.44,15.72,3.62,21.86h-36.91c-.9-2.6-1.53-7.04-1.32-9.63h-.37c-7.84,8.85-19.16,11.38-31.03,11.32-18.55-.12-33.89-9.11-33.78-29.33.18-30.42,35.78-29.09,54.53-32.5,5.01-.9,10.03-2.36,10.07-8.48.04-6.49-6.06-8.94-12-8.98-11.32-.06-13.57,5.67-13.77,9.75l-34.15-.19c1.27-27.08,26.9-31.39,49.71-31.24,46,.26,45.52,19.36,45.41,37.91v39.51Z"></path>
                <path d="M305.73,107.88c26.08,11.65,53.13,16.82,82.61,16.99,30.97.18,54.46-5.67,84.19-16.99l-.17,32.08c-26.61,13.2-55.47,20.31-84.23,20.15-31.34-.19-53.93-6.62-82.6-20.15l.19-32.08Z"></path>
            </g>
            
            </g>
        </g>
        </svg>
    
        </div>
           <p>
               Taboola Best Practice Layout is a WordPress plugin that generates optimized pages using Blocks based on Taboola's best practices 
               with just a single click.
            </p>
            <hr class="mt-5"/>
          
          <p>In order to optimize your campaign and achieve best performance, we included the Taboola tracking pixel in this plugin. To activate it please add here your Taboola account ID:</p>
          <form method="post" action="">
              <label for="tbla_account_id">Taboola account ID</label>
              <input type="text" id="tbla_account_id" name="tbla_account_id" value="<?php echo esc_attr($tbla_account_id); ?>" size="20" />
              <input type="hidden" id="tbla_pre_account_id"  value="<?php echo get_option('tbla_account_id'); ?>"  />
              <input type="submit" name="submit_tbla_account_id" value="Save" class="tbpl-button tbpl-button-small">
          </form>


          <p>
              After adding and saving your Taboola account ID, you can create a new page based on Taboola's best practices with just a single click.
            </p>
            
          
           <form method="post" >
            <p>To track the click out from the landing page, please add here a name for the event: <input type="text" name="tbla_event"></p>

            <p>
               <ol>
                   <li>Click the button below to get started.</li>
                   <li>A new page, based on your existing template setup, will be instantly created under "Pages"</li>
                   <li>You can then customize the content of the page to fit your campaign content and other preferences.</li>
               </ol>
            </p>
            <p>
                Please note, you should have the same exact event name in your Taboola Ads account setup. For more info check our 
                <a href="https://help.taboola.com/hc/en-us/articles/360003484314-Defining-and-Creating-Conversions" target="_blank"> help center page.</a>
            </p>
               <input type="submit" id="submit_tbla_create_page" name="submit_tbla_create_page" value="Create Page" class="tbpl-button mb-3" >
               <p class="error hidden" id="tbla_account_id_error">Taboola account ID is required</p>
               <p class="error hidden" id="tbla_pre_account_id_error">Please save your Taboola account ID before creating a page </p>
           </form>

          
    </div>
</div>
    <?php
}
